@@ -11,7 +11,7 @@ from pandas.api.types import (
     is_object_dtype,
 )
 
-from profiling.utils import vega_sanitize
+from profiling.utils import format_time, vega_sanitize
 
 
 def partialdep(func: Callable[[pd.DataFrame], pd.Series], x: pd.DataFrame, var: str):
@@ -51,9 +51,12 @@ def partialdep_num(
         x = x.iloc[id_sample]
 
     # Determine evaluation points (deciles)
-    if x[var].nunique() >= 10:
+    n_cut = 10
+    if x[var].nunique() >= n_cut:
         quantiles = np.quantile(
-            x[var], q=np.linspace(0.1, 0.9, 9), interpolation="nearest"
+            x[var],
+            q=np.linspace(1 / (2 * n_cut), 1 - (1 / (2 * n_cut)), n_cut - 1),
+            interpolation="nearest",
         )
     else:
         quantiles = np.sort(x[var].unique())
@@ -175,7 +178,9 @@ def partialdep_cat(
         .encode(
             x=alt.X("Predicted Value", scale=alt.Scale(zero=False)),
             y=alt.Y(
-                var_sanitized, sort=ordered_categories, scale=alt.Scale(zero=False),
+                var_sanitized,
+                sort=ordered_categories,
+                scale=alt.Scale(zero=False),
             ),
             detail="id",
         )
@@ -186,9 +191,14 @@ def partialdep_cat(
         .encode(
             x="Predicted Value",
             y=alt.Y(
-                var_sanitized, sort=ordered_categories, scale=alt.Scale(zero=False),
+                var_sanitized,
+                sort=ordered_categories,
+                scale=alt.Scale(zero=False),
             ),
-            tooltip=[var_sanitized, alt.Tooltip(f"Predicted Value:Q", format=".2f"),],
+            tooltip=[
+                alt.Tooltip(var_sanitized),
+                alt.Tooltip(f"Predicted Value:Q", format=".2f"),
+            ],
         )
         .interactive()
     )
@@ -211,9 +221,12 @@ def partialdep_datetime(
         x = x.iloc[id_sample]
 
     # Determine evaluation points (deciles)
-    if x[var].nunique() >= 10:
+    n_cut = 10
+    if x[var].nunique() >= n_cut:
         quantiles = np.quantile(
-            x[var], q=np.linspace(0.1, 0.9, 9), interpolation="nearest"
+            x[var],
+            q=np.linspace(1 / (2 * n_cut), 1 - (1 / (2 * n_cut)), n_cut - 1),
+            interpolation="nearest",
         )
     else:
         quantiles = np.sort(x[var].unique())
@@ -243,6 +256,9 @@ def partialdep_datetime(
     # Create plot
     var_sanitized = vega_sanitize(var, datatype="T")
 
+    # Format datetimes correctly
+    formatted_time = format_time(x, var)
+
     lines = (
         alt.Chart(df_ice)
         .mark_line(strokeOpacity=0.3, color="grey", strokeWidth=2)
@@ -259,7 +275,7 @@ def partialdep_datetime(
             x=var_sanitized,
             y=alt.Y("Predicted Value:Q", scale=alt.Scale(zero=False)),
             tooltip=[
-                alt.Tooltip(var_sanitized, format=".2f"),
+                alt.Tooltip(var_sanitized, format=formatted_time),
                 alt.Tooltip(f"Predicted Value:Q", format=".2f"),
             ],
         )
